/*
 * Copyright (C) 1996-2023 The Squid Software Foundation and contributors
 *
 * Squid software is distributed under GPLv2+ license and includes
 * contributions from numerous individuals and organizations.
 * Please see the COPYING and CONTRIBUTORS files for details.
 */

#include "squid.h"
#include "mime_header.h"
#include "sbuf/SBuf.h"

#define STUB_API "mime.cc"
#include "tests/STUB.h"

size_t headersEnd(const char *, size_t, bool &) STUB_RETVAL(0)
size_t headersEnd(const SBuf &, bool &) STUB_RETVAL(0)

